@@ -11,16 +11,15 @@ import auto_editor.vanparse as vanparse
 import auto_editor.utils.func as usefulfunctions
 
 from auto_editor.utils.progressbar import ProgressBar
-from auto_editor.utils.func import set_output_name
 from auto_editor.utils.log import Log, Timer
-from auto_editor.ffwrapper import FFmpeg
+from auto_editor.ffwrapper import FFmpeg, FileInfo
 from auto_editor.edit import edit_media
 
 def main_options(parser):
     from auto_editor.objects import (TextObject, RectangleObject, EllipseObject,
         ImageObject)
     from auto_editor.utils.types import (file_type, float_type, sample_rate_type,
-        frame_type, range_type, speed_range_type, block_type, margin_type, color_type)
+        frame_type, range_type, speed_range_type, margin_type, color_type)
 
     parser.add_text('Object Options')
     parser.add_argument('--add-text', nargs='*', dataclass=TextObject,
@@ -43,30 +42,12 @@ def main_options(parser):
         help='The directory where the downloaded URL is placed.')
     parser.add_argument('--limit-rate', '-rate', default='3m',
         help='The maximum download rate in bytes per second (50k, 4.2m)')
-    parser.add_argument('--id', type=str, default=None,
-        help='Manually set the YouTube ID the video belongs to.')
-    parser.add_argument('--block', type=block_type,
-        help='Given a SponsorBlock category, mark the section as silent.',
-        manual='Multiple categories can be specified by using a comma: "sponsor,intro"\n'
-            'This option only works on YouTube URLs, or where `--id` points to a valid '
-            'YouTube ID.\n\nCategories include: '
-            'sponsor intro outro selfpromo interaction music_offtopic')
     parser.add_argument('--download-archive', type=file_type, default=None,
         help='Download only videos not listed in archive file. Record the IDs of'
              ' all downloads.')
     parser.add_argument('--cookies', type=file_type, default=None,
         help='The file to read cookies from and dump the cookie jar in.')
 
-    parser.add_text('Motion Detection Options')
-    parser.add_argument('--motion-threshold', type=float_type, default=0.02,
-        range='0 to 1',
-        help='How much motion is required to be considered "moving"')
-    parser.add_blank()
-    parser.add_argument('--md-width', type=int, default=400, range='1 to Infinity',
-        help="Scale the frame to this width before being compared.")
-    parser.add_argument('--md-blur', type=int, default=9, range='0 to Infinity',
-        help='Set the strength of the blur applied to a frame before being compared.')
-
     parser.add_text('Exporting as Media Options')
     parser.add_argument('--video-codec', '-vcodec', '-c:v', default='auto',
         help='Set the video codec for the output media file.')
@@ -78,24 +59,13 @@ def main_options(parser):
         help='Set the number of bits per second for audio.')
     parser.add_argument('--sample-rate', '-ar', type=sample_rate_type,
         help='Set the sample rate of the input and output videos.')
-    parser.add_argument('--preset', '-preset', default='unset',
-        choices=['ultrafast', 'superfast', 'veryfast', 'faster', 'fast', 'medium',
-            'slow', 'slower', 'veryslow', 'unset'],
-        help='Set the preset for ffmpeg to help save file size or increase quality.')
-    parser.add_argument('--tune', '-tune', default='unset',
-        choices=['film', 'animation', 'grain', 'stillimage', 'fastdecode',
-            'zerolatency', 'none', 'unset'],
-        help='Set the tune for ffmpeg to compress video better in certain circumstances.')
-    parser.add_argument('--constant-rate-factor', '-crf', default='unset', range='0 to 51',
-        help='Set a value to the ffmpeg option -crf.',
-        manual="This option's value gets directly passed to the -crf flag used by ffmpeg "
-        "during encoding. If the video encoder does not support crf, "
-        "the program will error.")
     parser.add_argument('--video-quality-scale', '-qscale:v', '-q:v', default='unset',
         range='1 to 31',
         help='Set a value to the ffmpeg option -qscale:v')
     parser.add_argument('--scale', type=float_type, default=1,
         help='Scale the output video by a certain factor.')
+    parser.add_argument('--extras',
+        help='Add extra options for ffmpeg for video rendering. Must be in quotes.')
 
     parser.add_text('Miscellaneous Options')
     parser.add_argument('--background', type=color_type, default='#000',
@@ -129,38 +99,66 @@ def main_options(parser):
 
     parser.add_text('Select Editing Source Options')
     parser.add_argument('--edit-based-on', '--edit', default='audio',
-        choices=['audio', 'motion', 'none', 'all', 'not_audio', 'not_motion',
-            'audio_or_motion', 'audio_and_motion', 'audio_xor_motion',
-            'audio_and_not_motion', 'not_audio_and_motion', 'not_audio_and_not_motion'],
-        help='Decide which method to use when making edits.')
+        help='Decide which method to use when making edits.',
+        manual='''Editing Methods:
+ - audio:
+    General audio detection.
+ - motion:
+    Motion detection specialized for real life noisy video.
+ - pixeldiff:
+    Detect when a certain amount of pixels have changed between frames.
+ - none:
+    Do not modify the media in anyway. (Mark all sections as "loud")
+ - all:
+    Cut out everything out. (Mark all sections as "silent")
+
+Editing Methods Attributes:
+ - audio: 2
+    - stream: 0 : Union[int, 'all']
+    - threshold: args.silent_threshold : float_type
+ - motion: 3
+    - threshold: 2% : float_type
+    - blur: 9 : int
+    - width: 400 : int
+ - pixeldiff: 2
+    - threshold: 1 : int
+ - none: 0
+ - all: 0
+
+Logical Operators:
+ - and
+ - or
+ - xor
+
+Examples:
+  --edit audio
+  --edit audio:stream=1
+  --edit audio:threshold=4%
+  --edit audio:threshold=0.03
+  --edit motion
+  --edit motion:threshold=2%,blur=3
+  --edit audio:threshold=4% or motion:threshold=2%,blur=3
+  --edit none
+  --edit all''')
+
     parser.add_argument('--keep-tracks-seperate', action='store_true',
         help="Don't combine audio tracks when exporting.")
     parser.add_blank()
     parser.add_argument('--cut-by-this-audio', '-ca', type=file_type,
         help="Base cuts by this audio file instead of the video's audio.")
-    parser.add_argument('--cut-by-this-track', '-ct', type=int, default=0,
-        range='0 to the number of audio tracks minus one',
-        help='Base cuts by a different audio track in the video.')
-    parser.add_argument('--cut-by-all-tracks', '-cat', action='store_true',
-        help='Combine all audio tracks into one before basing cuts.')
 
-    parser.add_text('Export Mode Options')
-    parser.add_argument('--export-to-premiere', '-exp', action='store_true',
-        help='Export as an XML file for Adobe Premiere Pro instead of making a media file.')
-    parser.add_argument('--export-to-final-cut-pro', '-exf', action='store_true',
-        help='Export as an XML file for Final Cut Pro instead of making a media file.')
-    parser.add_argument('--export-to-shotcut', '-exs', action='store_true',
-        help='Export as an XML timeline file for Shotcut instead of making a media file.')
-    parser.add_argument('--export-as-json', action='store_true',
-        help='Export as a JSON file that can be read by auto-editor later.')
-    parser.add_argument('--export-as-audio', '-exa', action='store_true',
-        help='Export as a WAV audio file.')
-    parser.add_argument('--export-as-clip-sequence', '-excs', action='store_true',
-        help='Export as multiple numbered media files.')
-    parser.add_argument('--timeline', action='store_true',
-        help='Display timeline JSON file and halt.',
-        manual='This option is like `--export-as-json` except that it outputs directly '
-            'to stdout instead of to a file.')
+    parser.add_argument('--export', default='default',
+        choices=['default', 'premiere', 'final-cut-pro', 'shotcut', 'json', 'audio', 'clip-sequence'],
+        help='Choice the export mode.',
+        manual='Instead of exporting a video, export as one of these options instead.\n\n'
+            'default       : Export as usual\n'
+            'premiere      : Export as an XML timeline file for Adobe Premiere Pro\n'
+            'final-cut-pro : Export as an XML timeline file for Final Cut Pro\n'
+            'shotcut       : Export as an XML timeline file for Shotcut\n'
+            'json          : Export as an auto-editor JSON timeline file\n'
+            'audio         : Export as a WAV audio file\n'
+            'clip-sequence : Export as multiple numbered media files'
+    )
 
     parser.add_text('Utility Options')
     parser.add_argument('--no-open', action='store_true',
@@ -190,6 +188,10 @@ def main_options(parser):
         help='Display less output.')
     parser.add_argument('--preview', action='store_true',
         help='Show stats on how the input will be cut and halt.')
+    parser.add_argument('--timeline', action='store_true',
+        help='Show auto-editor JSON timeline file and halt.')
+    parser.add_argument('--api', default='0.2.0',
+        help='Set what version of the JSON timeline to output.')
 
     parser.add_text('Editing Options')
 
@@ -245,25 +247,56 @@ def main():
 
     parser = vanparse.ArgumentParser('Auto-Editor', auto_editor.version, description=desc)
 
-    subcommands = ['create', 'test', 'info', 'levels', 'grep', 'subdump', 'desc']
+    subcommands = ['test', 'info', 'levels', 'grep', 'subdump', 'desc']
 
     if len(sys.argv) > 1 and sys.argv[1] in subcommands:
-        obj = __import__('auto_editor.subcommands.{}'.format(sys.argv[1]),
-            fromlist=['subcommands'])
+        obj = __import__(f'auto_editor.subcommands.{sys.argv[1]}', fromlist=['subcommands'])
         obj.main(sys.argv[2:])
         sys.exit()
     else:
         parser = main_options(parser)
+
+        # Preserve backwards compatibility
+
+        sys_a = sys.argv[1:]
+
+        def c(sys_a, options, new):
+            for option in options:
+                if option in sys_a:
+                    pos = sys_a.index(option)
+                    sys_a[pos:pos+1] = new
+            return sys_a
+
+        sys_a = c(sys_a,
+            ['--export_to_premiere', '--export-to-premiere', '-exp'],
+            ['--export', 'premiere']
+        )
+        sys_a = c(sys_a,
+            ['--export_to_final_cut_pro', '--export-to-final-cut-pro', '-exf'],
+            ['--export', 'final-cut-pro']
+        )
+        sys_a = c(sys_a,
+            ['--export_to_shotcut', '--export-to-shotcut', '-exs'],
+            ['--export', 'shotcut']
+        )
+        sys_a = c(sys_a,
+            ['--export_as_json', '--export-as-json'],
+            ['--export', 'json']
+        )
+        sys_a = c(sys_a,
+            ['--export_as_clip_sequence', '--export-as-clip-sequence', '-excs'],
+            ['--export', 'clip-sequence']
+        )
+
         try:
-            args = parser.parse_args(sys.argv[1:])
+            args = parser.parse_args(sys_a)
         except vanparse.ParserError as e:
             Log().error(str(e))
 
     timer = Timer(args.quiet)
 
-    exporting_to_editor = (args.export_to_premiere or args.export_to_final_cut_pro or
-        args.export_to_shotcut)
-    making_data_file = exporting_to_editor or args.export_as_json
+    exporting_to_editor = args.export in ('premiere', 'final-cut-pro', 'shotcut')
+    making_data_file = exporting_to_editor or args.export == 'json'
 
     is64bit = '64-bit' if sys.maxsize > 2**32 else '32-bit'
 
@@ -309,36 +342,23 @@ def main():
         log.error('You need to give auto-editor an input file or folder so it can '
             'do the work for you.')
 
-    if([args.export_to_premiere, args.export_to_final_cut_pro, args.export_as_audio,
-        args.export_to_shotcut, args.export_as_clip_sequence].count(True) > 1):
-        log.error('You must choose only one export option.')
-
-    if args.constant_rate_factor != 'unset':
-        if int(args.constant_rate_factor) < 0 or int(args.constant_rate_factor) > 51:
-            log.error('Constant rate factor (crf) must be between 0-51.')
-    if args.md_width < 1:
-        log.error('--md-width cannot be less than 1.')
-
-    def write_starting_message(args) -> str:
-        if args.export_to_premiere:
+    def write_starting_message(export: str) -> str:
+        if export == 'premiere':
             return 'Exporting to Adobe Premiere Pro XML file'
-        if args.export_to_final_cut_pro:
+        if export == 'final-cut-pro':
             return 'Exporting to Final Cut Pro XML file'
-        if args.export_to_shotcut:
+        if export == 'shotcut':
             return 'Exporting to Shotcut XML Timeline file'
-        if args.export_as_audio:
+        if export == 'audio':
             return 'Exporting as audio'
         return 'Starting'
 
     if not args.preview and not args.timeline:
-        log.conwrite(write_starting_message(args))
+        log.conwrite(write_starting_message(args.export))
 
-    if args.preview or args.timeline or args.export_as_clip_sequence or making_data_file:
+    if args.preview or args.export not in ('audio', 'default'):
         args.no_open = True
 
-    if args.md_blur < 0:
-        args.md_blur = 0
-
     if args.silent_speed <= 0 or args.silent_speed > 99999:
         args.silent_speed = 99999
 
@@ -349,12 +369,7 @@ def main():
         args.output_file = []
 
     from auto_editor.validate_input import valid_input
-    input_list, segments = valid_input(args.input, ffmpeg, args, log)
-
-    if len(args.output_file) < len(input_list):
-        for i in range(len(input_list) - len(args.output_file)):
-            args.output_file.append(set_output_name(input_list[i], None,
-                making_data_file, args))
+    input_list = valid_input(args.input, ffmpeg, args, log)
 
     if args.combine_files:
         if exporting_to_editor:
@@ -365,25 +380,30 @@ def main():
         cmd = []
         for fileref in input_list:
             cmd.extend(['-i', fileref])
-        cmd.extend(['-filter_complex', '[0:v]concat=n={}:v=1:a=1'.format(len(input_list)),
-            '-codec:v', 'h264', '-pix_fmt', 'yuv420p', '-strict', '-2', temp_file])
+        cmd.extend([
+            '-filter_complex', f'[0:v]concat=n={len(input_list)}:v=1:a=1',
+            '-codec:v', 'h264',
+            '-pix_fmt', 'yuv420p',
+            '-strict', '-2',
+            temp_file,
+        ])
+
         ffmpeg.run(cmd)
         del cmd
         input_list = [temp_file]
 
-    def main_loop(input_list, ffmpeg, args, segments, log):
+    def main_loop(input_list, ffmpeg, args, log):
         num_cuts = 0
 
         progress = ProgressBar(args.progress)
 
         for i, input_path in enumerate(input_list):
-            inp = ffmpeg.file_info(input_path)
+            inp = FileInfo(input_path, ffmpeg)
 
             if len(input_list) > 1:
                 log.conwrite(f'Working on {inp.basename}')
 
-            cuts, output_path = edit_media(i, inp, ffmpeg, args, progress,
-                segments[i], exporting_to_editor, making_data_file, TEMP, log)
+            cuts, output_path = edit_media(i, inp, ffmpeg, args, progress, TEMP, log)
             num_cuts += cuts
 
         if not args.preview and not args.timeline and not making_data_file:
@@ -394,14 +414,16 @@ def main():
             time_save = usefulfunctions.human_readable_time(num_cuts * 30)
             s = 's' if num_cuts != 1 else ''
 
-            log.print('Auto-Editor made {} cut{}, which would have taken about {} if '
-                'edited manually.'.format(num_cuts, s, time_save))
+            log.print(
+                f'Auto-Editor made {num_cuts} cut{s}, which would have taken '
+                f'about {time_save} if edited manually.'
+            )
 
         if not args.no_open:
             usefulfunctions.open_with_system_default(output_path, log)
 
     try:
-        main_loop(input_list, ffmpeg, args, segments, log)
+        main_loop(input_list, ffmpeg, args, log)
     except KeyboardInterrupt:
         log.error('Keyboard Interrupt')
     log.cleanup()
