@@ -1,21 +1,19 @@
 import sys
+from typing import Tuple
 
 import av
 import numpy as np
-from PIL import Image, ImageOps, ImageChops, ImageFilter
+from PIL import ImageOps, ImageChops, ImageFilter
 
 from auto_editor.utils.progressbar import ProgressBar
 
 
-def new_size(size, width):
+def new_size(size: Tuple[int, int], width: int) -> Tuple[int, int]:
     h, w = size
-    r = width / w
-    return width, int(h * r)
+    return width, int(h * (width / w))
 
 
-def display_motion_levels(path: str, width: int, blur: int):
-
-    # TODO: Overwrite level when index is repeated. (Occurs in VFR videos)
+def display_motion_levels(path: str, fps: float, width: int, blur: int) -> None:
 
     container = av.open(path, 'r')
 
@@ -46,7 +44,7 @@ def display_motion_levels(path: str, width: int, blur: int):
         if prev_image is not None:
             count = np.count_nonzero(ImageChops.difference(prev_image, image))
 
-            sys.stdout.write('{:.20f}\n'.format(count))
+            sys.stdout.write(f'{count / total_pixels:.20f}\n')
 
 
 def motion_detection(path: str, fps: float, threshold: float, progress: ProgressBar,
