@@ -1,82 +1,22 @@
-from typing import List, Tuple, NoReturn, Optional, Union
+from typing import List, Tuple, NoReturn, Union
 
 import numpy as np
 
 from auto_editor.utils.log import Log
 from auto_editor.utils.types import split_num_str
 
-def combine_audio_motion(
-    audio_list: np.ndarray, motion_list: np.ndarray, based: str, log: Log
-    ) -> Optional[np.ndarray]:
 
-    no_place_where = "There was no place where {} exceeded the threshold."
-
-    if (based == 'audio' or based == 'not_audio') and max(audio_list) == 0:
-        log.error(no_place_where.format('audio'))
-
-    if (based == 'motion' or based == 'not_motion') and max(motion_list) == 0:
-        log.error(no_place_where.format('motion'))
-
-    if audio_list is not None and max(audio_list) == 0:
-        log.warning(no_place_where.format('audio'))
-
-    if motion_list is not None and max(motion_list) == 0:
-        log.warning(no_place_where.format('motion'))
-
-    if based == 'audio':
-        return audio_list
-
-    if based == 'motion':
-        return motion_list
-
-    if based == 'not_audio':
-        return np.invert(audio_list)
-
-    if based == 'not_motion':
-        return np.invert(motion_list)
-
-    if based == 'audio_and_motion':
-        return audio_list & motion_list
-
-    if based == 'audio_or_motion':
-        return audio_list | motion_list
-
-    if based == 'audio_xor_motion':
-        return np.bitwise_xor(audio_list, motion_list)
-
-    if based == 'audio_and_not_motion':
-        return audio_list & np.invert(motion_list)
-
-    if based == 'not_audio_and_motion':
-        return np.invert(audio_list) & motion_list
-
-    if based == 'not_audio_and_not_motion':
-        return np.invert(audio_list) & np.invert(motion_list)
-    return None
-
-
-def combine_segment(has_loud: np.ndarray, segment, fps: float) -> np.ndarray:
-    for item in segment:
-        start, end = item['segment']
-        start = int(start * fps)
-        end = int(end * fps)
-        has_loud[start:end] = False
-    return has_loud
-
-
-def remove_small(
-    has_loud: np.ndarray, lim: int, replace: int, with_: int
-    ) -> np.ndarray:
+def remove_small(has_loud: np.ndarray, lim: int, replace: int, with_: int) -> np.ndarray:
     startP = 0
     active = False
     for j, item in enumerate(has_loud):
         if item == replace:
-            if(not active):
+            if not active:
                 startP = j
                 active = True
             # Special case for end.
             if j == len(has_loud) - 1:
-                if(j - startP < lim):
+                if j - startP < lim:
                     has_loud[startP:j+1] = with_
         else:
             if active:
@@ -152,13 +92,13 @@ def cook(has_loud: np.ndarray, min_clip: int, min_cut: int) -> np.ndarray:
 # Turn long silent/loud array to formatted chunk list.
 # Example: [1, 1, 1, 2, 2] => [(0, 3, 1), (3, 5, 2)]
 def chunkify(arr: np.ndarray, arr_length: int = None) -> List[Tuple[int, int, float]]:
-    if(arr_length is None):
+    if arr_length is None:
         arr_length = len(arr)
 
     chunks = []
     start = 0
     for j in range(1, arr_length):
-        if(arr[j] != arr[j - 1]):
+        if arr[j] != arr[j - 1]:
             chunks.append((start, j, arr[j - 1]))
             start = j
     chunks.append((start, arr_length, arr[j]))
@@ -173,8 +113,8 @@ def apply_margin(
     start_index = []
     end_index = []
     for j in range(1, has_loud_length):
-        if(has_loud[j] != has_loud[j - 1]):
-            if(has_loud[j]):
+        if has_loud[j] != has_loud[j - 1]:
+            if has_loud[j]:
                 start_index.append(j)
             else:
                 end_index.append(j)
@@ -227,9 +167,9 @@ def merge(start_list: np.ndarray, end_list: np.ndarray) -> np.ndarray:
 
     startP = 0
     for item in start_list:
-        if(item == True):
+        if item == True:
             where_list = np.where(end_list[startP:])[0]
-            if(len(where_list) > 0):
+            if len(where_list) > 0:
                 merge[startP:where_list[0]] = True
         startP += 1
     return merge
