@@ -2,7 +2,8 @@
 import re
 import sys
 import os.path
-from subprocess import Popen, call, PIPE
+import subprocess
+from subprocess import Popen, PIPE
 from platform import system
 
 # Typing
@@ -68,16 +69,18 @@ class FFmpeg:
         if not self.debug:
             cmd.extend(['-nostats', '-loglevel', 'error'])
         self.print_cmd(cmd)
-        call(cmd)
+        subprocess.run(cmd)
 
-    def run_check_errors(self, cmd: List[str], log: Log, show_out: bool=False) -> None:
+    def run_check_errors(
+        self, cmd: List[str], log: Log, show_out: bool=False, path=None
+    ) -> None:
 
         def _run(cmd: List[str]) -> Any:
             process = self.Popen(cmd, stdin=PIPE, stdout=PIPE, stderr=PIPE)
 
             _, stderr = process.communicate()
             process.stdin.close()
-            return stderr.decode()
+            return stderr.decode('utf-8', 'replace')
 
         output = _run(cmd)
 
@@ -95,6 +98,8 @@ class FFmpeg:
             r"Undefined constant or missing '.*' in '.*'",
             r'DLL .* failed to open',
             r"Incompatible pixel format '.*' for codec '[A-Za-z0-9_]*'",
+            r"Unrecognized option '.*'",
+            r"Permission denied",
         ]
 
         if self.debug:
@@ -105,13 +110,12 @@ class FFmpeg:
             if check:
                 log.error(check.group())
 
-        if show_out and not self.debug:
+        if path is not None and not os.path.isfile(path):
+            print(output)
+            log.error(f'The file {path} was not created.')
+        elif show_out and not self.debug:
             print(f'stderr: {output}')
 
-    def file_info(self, path):
-        # type: (str) -> File
-        return File(self, path)
-
     def Popen(self, cmd: List[str], stdin=None, stdout=PIPE, stderr=None):
         cmd = [self.path] + cmd
         self.print_cmd(cmd)
@@ -126,11 +130,11 @@ class FFmpeg:
         return output
 
 
-class File:
+class FileInfo:
     __slots__ = ('path', 'abspath', 'basename', 'dirname', 'name', 'ext', 'duration',
         'bitrate', 'metadata', 'fps', 'video_streams', 'audio_streams', 'subtitle_streams')
 
-    def __init__(self, ffmpeg: FFmpeg, path: str):
+    def __init__(self, path: str, ffmpeg: FFmpeg):
         self.path = path
         self.abspath = os.path.abspath(path)
         self.basename = os.path.basename(path)
@@ -156,7 +160,7 @@ class File:
 
                 if body is not None:
                     if key is None:
-                        if(active_key is not None):
+                        if active_key is not None:
                             self.metadata[active_key] += '\n' + body
                     else:
                         self.metadata[key] = body
