@@ -1,3 +1,13 @@
+"""
+Premiere Pro uses the Final Cut Pro 7 XML Interchange Format
+
+See docs here:
+https://developer.apple.com/library/archive/documentation/AppleApplications/Reference/FinalCutPro_XML/Elements/Elements.html
+
+Also, Premiere itself will happily output subtlety incorrect XML files that don't
+come back the way they started.
+"""
+
 import os.path
 from os.path import abspath
 from shutil import move
@@ -8,7 +18,6 @@ from .utils import indent, get_width_height, safe_mkdir
 
 PIXEL_ASPECT_RATIO = 'square'
 COLORDEPTH = '24'
-NTSC = 'FALSE'
 ANAMORPHIC = 'FALSE'
 DEPTH = '16'
 
@@ -45,13 +54,32 @@ def speedup(speed: float) -> str:
         '\t\t</parameter>', '\t</effect>', '</filter>')
 
 
-def premiere_xml(inp, temp, output, chunks, sampleRate, fps, log):
+def premiere_xml(inp, temp, output, chunks, sample_rate, fps, log):
 
     audio_file = len(inp.video_streams) == 0 and len(inp.audio_streams) == 1
 
-    clips = list(filter(lambda chunk: chunk[2] != 99999, chunks))
+    # This is not at all how timebase works in actual media but that's how it works here.
+    timebase = int(fps)
+
+    if fps == 23.98 or fps == 23.97602397 or fps == 23.976:
+        timebase = 24
+        ntsc = 'TRUE'
+    elif fps == 29.97 or fps == 29.97002997:
+        timebase = 30
+        ntsc = 'TRUE'
+    elif fps == 59.94 or fps == 59.94005994:
+        timebase = 60
+        ntsc = 'TRUE'
+    else:
+        ntsc = 'FALSE'
 
     duration = chunks[-1][1]
+
+    clips = []
+    for chunk in chunks:
+        if chunk[2] != 99999:
+            clips.append(chunk)
+
     pathurls = [fix_url(inp.path)]
 
     tracks = len(inp.audio_streams)
@@ -71,8 +99,6 @@ def premiere_xml(inp, temp, output, chunks, sampleRate, fps, log):
     if width is None or height is None:
         width, height = '1280', '720'
 
-    timebase = str(int(fps))
-
     group_name = 'Auto-Editor {} Group'.format('Audio' if audio_file else 'Video')
 
     with open(output, 'w', encoding='utf-8') as outfile:
@@ -83,7 +109,7 @@ def premiere_xml(inp, temp, output, chunks, sampleRate, fps, log):
         outfile.write(f'\t\t<duration>{duration}</duration>\n')
         outfile.write('\t\t<rate>\n')
         outfile.write(f'\t\t\t<timebase>{timebase}</timebase>\n')
-        outfile.write(f'\t\t\t<ntsc>{NTSC}</ntsc>\n')
+        outfile.write(f'\t\t\t<ntsc>{ntsc}</ntsc>\n')
         outfile.write('\t\t</rate>\n')
         outfile.write('\t\t<media>\n')
         outfile.write(indent(3,
@@ -97,13 +123,13 @@ def premiere_xml(inp, temp, output, chunks, sampleRate, fps, log):
             outfile.write(indent(3,
                 '\t\t\t<rate>',
                 f'\t\t\t\t<timebase>{timebase}</timebase>',
-                f'\t\t\t\t<ntsc>{NTSC}</ntsc>',
+                f'\t\t\t\t<ntsc>{ntsc}</ntsc>',
                 '\t\t\t</rate>')
             )
 
         outfile.write(indent(3,
-            '\t\t\t<width>{}</width>'.format(width),
-            '\t\t\t<height>{}</height>'.format(height),
+            f'\t\t\t<width>{width}</width>',
+            f'\t\t\t<height>{height}</height>',
             f'\t\t\t<pixelaspectratio>{PIXEL_ASPECT_RATIO}</pixelaspectratio>',
         ))
 
@@ -127,21 +153,23 @@ def premiere_xml(inp, temp, output, chunks, sampleRate, fps, log):
             total = 0
             for j, clip in enumerate(clips):
 
-                clip_duration = (clip[1] - clip[0]) / clip[2]
+                clip_duration = (clip[1] - clip[0] + 1) / clip[2]
 
-                my_start = int(total)
-                my_end = int(total) + int(clip_duration)
+                _start = int(total)
+                _end = int(total) + int(clip_duration)
+                _in = int(clip[0] / clip[2])
+                _out = int(clip[1] / clip[2])
 
                 total += clip_duration
 
                 outfile.write(indent(5,
                     '<clipitem id="clipitem-{}">'.format(j+1),
                     '\t<masterclipid>masterclip-2</masterclipid>',
-                    '\t<name>{}</name>'.format(inp.basename),
-                    '\t<start>{}</start>'.format(my_start),
-                    '\t<end>{}</end>'.format(my_end),
-                    '\t<in>{}</in>'.format(int(clip[0] / clip[2])),
-                    '\t<out>{}</out>'.format(int(clip[1] / clip[2]))
+                    f'\t<name>{inp.basename}</name>',
+                    f'\t<start>{_start}</start>',
+                    f'\t<end>{_end}</end>',
+                    f'\t<in>{_in}</in>',
+                    f'\t<out>{_out}</out>',
                     )
                 )
 
@@ -152,7 +180,7 @@ def premiere_xml(inp, temp, output, chunks, sampleRate, fps, log):
                         '\t<pathurl>{}</pathurl>'.format(pathurls[0]),
                         '\t<rate>',
                         f'\t\t<timebase>{timebase}</timebase>',
-                        f'\t\t<ntsc>{NTSC}</ntsc>',
+                        f'\t\t<ntsc>{ntsc}</ntsc>',
                         '\t</rate>',
                         f'\t<duration>{duration}</duration>',
                         '\t<media>',
@@ -160,10 +188,10 @@ def premiere_xml(inp, temp, output, chunks, sampleRate, fps, log):
                         '\t\t\t<samplecharacteristics>',
                         '\t\t\t\t<rate>',
                         f'\t\t\t\t\t<timebase>{timebase}</timebase>',
-                        f'\t\t\t\t\t<ntsc>{NTSC}</ntsc>',
+                        f'\t\t\t\t\t<ntsc>{ntsc}</ntsc>',
                         '\t\t\t\t</rate>',
-                        '\t\t\t\t<width>{}</width>'.format(width),
-                        '\t\t\t\t<height>{}</height>'.format(height),
+                        f'\t\t\t\t<width>{width}</width>',
+                        f'\t\t\t\t<height>{height}</height>',
                         f'\t\t\t\t<anamorphic>{ANAMORPHIC}</anamorphic>',
                         f'\t\t\t\t<pixelaspectratio>{PIXEL_ASPECT_RATIO}</pixelaspectratio>',
                         '\t\t\t\t<fielddominance>none</fielddominance>',
@@ -172,7 +200,7 @@ def premiere_xml(inp, temp, output, chunks, sampleRate, fps, log):
                         '\t\t<audio>',
                         '\t\t\t<samplecharacteristics>',
                         f'\t\t\t\t<depth>{DEPTH}</depth>',
-                        f'\t\t\t\t<samplerate>{sampleRate}</samplerate>',
+                        f'\t\t\t\t<samplerate>{sample_rate}</samplerate>',
                         '\t\t\t</samplecharacteristics>',
                         '\t\t\t<channelcount>2</channelcount>',
                         '\t\t</audio>',
@@ -183,23 +211,23 @@ def premiere_xml(inp, temp, output, chunks, sampleRate, fps, log):
                 else:
                     outfile.write('\t\t\t\t\t\t<file id="file-1"/>\n')
 
-                if(clip[2] != 1):
+                if clip[2] != 1:
                     outfile.write(speedup(clip[2] * 100))
 
                 # Linking for video blocks
                 for i in range(max(3, tracks + 1)):
                     outfile.write('\t\t\t\t\t\t<link>\n')
                     outfile.write('\t\t\t\t\t\t\t<linkclipref>clipitem-{}</linkclipref>\n'.format((i*(len(clips)))+j+1))
-                    if(i == 0):
+                    if i == 0:
                         outfile.write('\t\t\t\t\t\t\t<mediatype>video</mediatype>\n')
                     else:
                         outfile.write('\t\t\t\t\t\t\t<mediatype>audio</mediatype>\n')
-                    if(i == 2):
+                    if i == 2:
                         outfile.write('\t\t\t\t\t\t\t<trackindex>2</trackindex>\n')
                     else:
                         outfile.write('\t\t\t\t\t\t\t<trackindex>1</trackindex>\n')
                     outfile.write('\t\t\t\t\t\t\t<clipindex>{}</clipindex>\n'.format(j+1))
-                    if(i > 0):
+                    if i > 0:
                         outfile.write('\t\t\t\t\t\t\t<groupindex>1</groupindex>\n')
                     outfile.write('\t\t\t\t\t\t</link>\n')
 
@@ -214,7 +242,7 @@ def premiere_xml(inp, temp, output, chunks, sampleRate, fps, log):
             '\t<format>',
             '\t\t<samplecharacteristics>',
             f'\t\t\t<depth>{DEPTH}</depth>',
-            f'\t\t\t<samplerate>{sampleRate}</samplerate>',
+            f'\t\t\t<samplerate>{sample_rate}</samplerate>',
             '\t\t</samplecharacteristics>',
             '\t</format>'
             )
@@ -225,10 +253,12 @@ def premiere_xml(inp, temp, output, chunks, sampleRate, fps, log):
             total = 0
             for j, clip in enumerate(clips):
 
-                clip_duration = (clip[1] - clip[0]) / clip[2]
+                clip_duration = (clip[1] - clip[0] + 1) / clip[2]
 
-                my_start = int(total)
-                my_end = int(total) + int(clip_duration)
+                _start = int(total)
+                _end = int(total) + int(clip_duration)
+                _in = int(clip[0] / clip[2])
+                _out = int(clip[1] / clip[2])
 
                 total += clip_duration
 
@@ -243,10 +273,10 @@ def premiere_xml(inp, temp, output, chunks, sampleRate, fps, log):
                     f'<clipitem id="clipitem-{clip_item_num}" premiereChannelType="stereo">',
                     f'\t<masterclipid>masterclip-{master_id}</masterclipid>',
                     f'\t<name>{inp.basename}</name>',
-                    f'\t<start>{my_start}</start>',
-                    f'\t<end>{my_end}</end>',
-                    '\t<in>{}</in>'.format(int(clip[0] / clip[2])),
-                    '\t<out>{}</out>'.format(int(clip[1] / clip[2]))
+                    f'\t<start>{_start}</start>',
+                    f'\t<end>{_end}</end>',
+                    f'\t<in>{_in}</in>',
+                    f'\t<out>{_out}</out>',
                     )
                 )
 
@@ -257,13 +287,13 @@ def premiere_xml(inp, temp, output, chunks, sampleRate, fps, log):
                         '\t<pathurl>{}</pathurl>'.format(pathurls[t]),
                         '\t<rate>',
                         f'\t\t<timebase>{timebase}</timebase>',
-                        f'\t\t<ntsc>{NTSC}</ntsc>',
+                        f'\t\t<ntsc>{ntsc}</ntsc>',
                         '\t</rate>',
                         '\t<media>',
                         '\t\t<audio>',
                         '\t\t\t<samplecharacteristics>',
                         f'\t\t\t\t<depth>{DEPTH}</depth>',
-                        f'\t\t\t\t<samplerate>{sampleRate}</samplerate>',
+                        f'\t\t\t\t<samplerate>{sample_rate}</samplerate>',
                         '\t\t\t</samplecharacteristics>',
                         '\t\t\t<channelcount>2</channelcount>',
                         '\t\t</audio>',
