@@ -1,21 +1,27 @@
 # Internal Libraries
 from datetime import timedelta
 
+# Typing
+from typing import List, Tuple, Union
+
 # Included Libraries
 from auto_editor.utils.func import get_new_length
+from auto_editor.utils.log import Log
+from auto_editor.ffwrapper import FileInfo
 
-def display_length(secs):
-    if(secs < 0):
+
+def display_length(secs: Union[int, float]) -> str:
+    if secs < 0:
         return '-' + str(timedelta(seconds=round(abs(secs))))
     return str(timedelta(seconds=round(secs)))
 
-def time_frame(title, frames, fps):
+def time_frame(title: str, frames: Union[int, float], fps: float) -> None:
     in_sec = round(frames / fps, 1)
     minutes = timedelta(seconds=round(in_sec))
-    print('{}: {} secs ({})'.format(title, in_sec, minutes))
+    print(f'{title}: {in_sec} secs ({minutes})')
 
 
-def preview(inp, chunks, log):
+def preview(inp: FileInfo, chunks: List[Tuple[int, int, float]], log: Log) -> None:
     fps = 30 if inp.fps is None else float(inp.fps)
 
     log.conwrite('')
@@ -38,7 +44,7 @@ def preview(inp, chunks, log):
     cut_lens = []
     clip_lens = []
     for chunk in chunks:
-        if(chunk[2] != 99999):
+        if chunk[2] != 99999:
             clips += 1
             leng = (chunk[1] - chunk[0]) / chunk[2]
             clip_lens.append(leng)
@@ -47,16 +53,16 @@ def preview(inp, chunks, log):
             leng = chunk[1] - chunk[0]
             cut_lens.append(leng)
 
-    print('clips: {}'.format(clips))
-    if(len(clip_lens) < 2):
+    print(f'clips: {clips}')
+    if len(clip_lens) < 2:
         time_frame(' - clip length', sum(clip_lens), fps)
     else:
         time_frame(' - smallest', min(clip_lens), fps)
         time_frame(' - largest', max(clip_lens), fps)
         time_frame(' - average', sum(clip_lens) / len(clip_lens), fps)
 
-    print('cuts: {}'.format(cuts))
-    if(len(cut_lens) < 2):
+    print(f'cuts: {cuts}')
+    if len(cut_lens) < 2:
         time_frame(' - cut length', sum(cut_lens), fps)
     else:
         time_frame(' - smallest', min(cut_lens), fps)
@@ -64,4 +70,4 @@ def preview(inp, chunks, log):
         time_frame(' - average', sum(cut_lens) / len(cut_lens), fps)
     print('')
 
-    log.debug('Chunks: {}'.format(chunks))
+    log.debug(f'Chunks: {chunks}')
