@@ -1,7 +1,9 @@
 import sys
 
 def levels_options(parser):
-    parser.add_argument('--kind', type=str, default='audio')
+    parser.add_argument('--kind', type=str, default='audio',
+        choices=['audio', 'motion', 'pixeldiff'],
+    )
     parser.add_argument('--track', type=int, default=0,
         help='Select the track to get. If `--kind` is set to motion, track will look '
             'at video tracks instead of audio.')
@@ -23,7 +25,7 @@ def main(sys_args=sys.argv[1:]):
     import auto_editor.vanparse as vanparse
 
     from auto_editor.utils.log import Log
-    from auto_editor.ffwrapper import FFmpeg
+    from auto_editor.ffwrapper import FFmpeg, FileInfo
 
     parser = vanparse.ArgumentParser('levels', auto_editor.version,
         description='Get loudness of audio over time.')
@@ -39,34 +41,41 @@ def main(sys_args=sys.argv[1:]):
 
     ffmpeg = FFmpeg(args.ffmpeg_location, args.my_ffmpeg, False)
 
-    inp = ffmpeg.file_info(args.input[0])
+    inp = FileInfo(args.input[0], ffmpeg)
     fps = 30 if inp.fps is None else float(inp.fps)
 
-    if(args.kind == 'audio'):
+    if args.kind == 'audio':
         from auto_editor.analyze.audio import display_audio_levels
 
-        if(args.track >= len(inp.audio_streams)):
-            log.error("Audio track '{}' does not exist.".format(args.track))
+        if args.track >= len(inp.audio_streams):
+            log.error(f"Audio track '{args.track}' does not exist.")
 
-        read_track = os.path.join(temp, '{}.wav'.format(args.track))
+        read_track = os.path.join(temp, f'{args.track}.wav')
 
-        ffmpeg.run(['-i', inp.path, '-ac', '2', '-map', '0:a:{}'.format(args.track),
-            read_track])
+        ffmpeg.run(['-i', inp.path, '-ac', '2', '-map', f'0:a:{args.track}', read_track])
 
-        if(not os.path.isfile(read_track)):
+        if not os.path.isfile(read_track):
             log.error('Audio track file not found!')
 
         display_audio_levels(read_track, fps)
 
-    if(args.kind == 'motion'):
-        if(args.track >= len(inp.video_streams)):
-            log.error("Video track '{}' does not exist.".format(args.track))
+    if args.kind == 'motion':
+        if args.track >= len(inp.video_streams):
+            log.error(f"Video track '{args.track}' does not exist.")
 
         from auto_editor.analyze.motion import display_motion_levels
 
-        display_motion_levels(inp.path, width=400, blur=9)
+        display_motion_levels(inp.path, fps, width=400, blur=9)
+
+    if args.kind == 'pixeldiff':
+        if args.track >= len(inp.video_streams):
+            log.error(f"Video track '{args.track}' does not exist.")
+
+        from auto_editor.analyze.pixeldiff import display_pixel_diff
+
+        display_pixel_diff(inp.path)
 
     log.cleanup()
 
-if(__name__ == '__main__'):
+if __name__ == '__main__':
     main()
