@@ -11,10 +11,9 @@ import av
 import numpy as np
 
 # Typing
-from typing import List, Tuple, Callable, NoReturn, Optional, Union
+from typing import List, Tuple, Callable, NoReturn, Optional
 
 # Included Libraries
-from auto_editor.utils.func import clean_list
 import auto_editor.vanparse as vanparse
 
 def test_options(parser):
@@ -59,8 +58,8 @@ def pipe_to_console(cmd: List[str]) -> Tuple[int, str, str]:
 def cleanup(the_dir: str) -> None:
     for item in os.listdir(the_dir):
         item = os.path.join(the_dir, item)
-        if ('_ALTERED' in item or item.endswith('.xml') or item.endswith('.json')
-            or item.endswith('.fcpxml') or item.endswith('.mlt')):
+        if ('_ALTERED' in item or item.endswith('.xml') or item.endswith('.fcpxml')
+            or item.endswith('.mlt')):
             os.remove(item)
         if item.endswith('_tracks'):
             shutil.rmtree(item)
@@ -71,7 +70,7 @@ def clean_all() -> None:
     cleanup(os.getcwd())
 
 
-def get_runner() -> list:
+def get_runner() -> List[str]:
     if platform.system() == 'Windows':
         return ['py', '-m', 'auto_editor']
     return ['python3', '-m', 'auto_editor']
@@ -86,7 +85,7 @@ def run_program(cmd: List[str]) -> None:
 
     returncode, stdout, stderr = pipe_to_console(cmd)
     if returncode > 0:
-        raise Exception('{}\n{}\n'.format(stdout, stderr))
+        raise Exception(f'{stdout}\n{stderr}\n')
 
 
 def check_for_error(cmd: List[str], match=None) -> None:
@@ -94,28 +93,28 @@ def check_for_error(cmd: List[str], match=None) -> None:
     if returncode > 0:
         if 'Error!' in stderr:
             if match is not None and match not in stderr:
-                raise Exception('Could\'t find "{}"'.format(match))
+                raise Exception(f'Could\'t find "{match}"')
         else:
-            raise Exception('Program crashed.\n{}\n{}'.format(stdout, stderr))
+            raise Exception(f'Program crashed.\n{stdout}\n{stderr}')
     else:
         raise Exception('Program should not respond with a code 0.')
 
 
 def make_np_list(in_file: str, compare_file: str, the_speed: float) -> None:
     from auto_editor.scipy.wavfile import read
-    from auto_editor.audiotsm2 import phasevocoder
-    from auto_editor.audiotsm2.io.array import ArrReader, ArrWriter
+    from auto_editor.render.tsm import phasevocoder, ArrReader, ArrWriter
 
-    samplerate, sped_chunk = read(in_file)
-    spedup_audio = np.zeros((0, 2), dtype=np.int16)
+    _, sped_chunk = read(in_file)
     channels = 2
 
-    with ArrReader(sped_chunk, channels, samplerate, 2) as reader:
-        with ArrWriter(spedup_audio, channels, samplerate, 2) as writer:
-            phasevocoder(reader.channels, speed=the_speed).run(
-                reader, writer
-            )
-            spedup_audio = writer.output
+    reader = ArrReader(sped_chunk)
+    writer = ArrWriter(np.zeros((0, 2), dtype=np.int16))
+
+    phasevocoder(channels, speed=the_speed).run(reader, writer)
+
+    spedup_audio = writer.output
+    del writer
+    del reader
 
     loaded = np.load(compare_file)
 
@@ -128,12 +127,12 @@ def make_np_list(in_file: str, compare_file: str, the_speed: float) -> None:
 
         result = np.subtract(spedup_audio, loaded['a'])
 
-        print('result non-zero: {}'.format(np.count_nonzero(result)))
-        print('len of spedup_audio: {}'.format(len(spedup_audio)))
+        print(f'result non-zero: {np.count_nonzero(result)}')
+        print(f'len of spedup_audio: {len(spedup_audio)}')
 
         print(np.count_nonzero(result) / spedup_audio.shape[0], 'difference between arrays')
 
-        raise Exception("file {} doesn't match array.".format(compare_file))
+        raise Exception(f"file {compare_file} doesn't match array.")
 
     # np.savez_compressed(out_file, a=spedup_audio)
 
@@ -191,6 +190,13 @@ def main(sys_args: Optional[List[str]]=None):
 
     ### Tests ###
 
+    ## API Tests ##
+
+    def read_api_0_1():
+        check_for_error(['resources/0.1-non-zero-start.json'], 'Error! First chunk must start with 0')
+        check_for_error(['resources/0.1-disjoint.json'], 'Error! Chunk disjointed at')
+
+
     def help_tests():
         """check the help option, its short, and help on options and groups."""
         run_program(['--help'])
@@ -212,7 +218,7 @@ def main(sys_args: Optional[List[str]]=None):
 
 
     def parser_test():
-        check_for_error(['example.mp4', '--block'], 'needs argument')
+        check_for_error(['example.mp4', '--video-speed'], 'needs argument')
 
 
     def subtitle_tests():
@@ -394,7 +400,6 @@ def main(sys_args: Optional[List[str]]=None):
 
 
     def track_tests():
-        run_program(['resources/multi-track.mov', '--cut_by_all_tracks'])
         run_program(['resources/multi-track.mov', '--keep_tracks_seperate'])
         run_program(['example.mp4', '--cut_by_this_audio', 'resources/newCommentary.mp3'])
 
@@ -426,16 +431,9 @@ def main(sys_args: Optional[List[str]]=None):
 
     def effect_tests():
         """Test rendering video objects"""
-        run_program(['create', 'test', '--width', '640', '--height', '360', '-o',
-            'testsrc.mp4'])
-        av_inspect('testsrc.mp4',
-            ('fps', 30),
-            ('resolution', (640, 360), ),
-        )
-        run_program(['testsrc.mp4', '--mark_as_loud', 'start,end', '--add_rectangle',
-            '0,30,0,200,100,300,fill=#43FA56,stroke=10'])
-        os.remove('testsrc_ALTERED.mp4')
-        os.remove('testsrc.mp4')
+        run_program(['resources/testsrc.mp4', '--mark_as_loud', 'start,end',
+            '--add_rectangle', '0,30,0,200,100,300,fill=#43FA56,stroke=10'])
+        os.remove('resources/testsrc_ALTERED.mp4')
 
 
     def render_text():
@@ -474,10 +472,50 @@ def main(sys_args: Optional[List[str]]=None):
 
 
     def motion_tests():
-        run_program(['resources/man_on_green_screen.mp4', '--edit_based_on', 'motion',
-            '--debug', '--frame_margin', '0', '-mcut', '0', '-mclip', '0'])
-        run_program(['resources/man_on_green_screen.mp4', '--edit_based_on', 'motion',
-            '--motion_threshold', '0'])
+        run_program(
+            ['resources/man_on_green_screen.mp4', '--edit', 'motion', '--debug',
+            '--frame_margin', '0', '-mcut', '0', '-mclip', '0']
+        )
+        run_program(
+            ['resources/man_on_green_screen.mp4', '--edit', 'motion:threshold=0']
+        )
+
+    def edit_positive_tests():
+        run_program(['resources/multi-track.mov', '--edit', 'audio:stream=all'])
+        run_program(['resources/multi-track.mov', '--edit', 'not audio:stream=all'])
+        run_program(['resources/multi-track.mov', '--edit', 'not audio:threshold=4% or audio:stream=1'])
+        #run_program(['resources/multi-track.mov', '--edit', 'not audio:threshold=4% or not audio:stream=1'])
+
+
+    def edit_negative_tests():
+        check_for_error(
+            ['resources/example_cut_s16le.wav', '--edit', 'motion'], "Video stream '0' does not exist"
+        )
+        check_for_error(
+            ['resources/man_on_green_screen.gif', '--edit', 'audio'], "Audio stream '0' does not exist"
+        )
+        check_for_error(
+            ['example.mp4', '--edit', 'not'], "Error! Dangling operand: 'not'"
+        )
+        check_for_error(
+            ['example.mp4', '--edit', 'audio and'], "Error! Dangling operand: 'and'"
+        )
+        check_for_error(
+            ['example.mp4', '--edit', 'and'], "Error! 'and' operand needs two arguments."
+        )
+        check_for_error(
+            ['example.mp4', '--edit', 'and audio'], "Error! 'and' operand needs two arguments."
+        )
+        check_for_error(
+            ['example.mp4', '--edit', 'or audio'], "Error! 'or' operand needs two arguments."
+        )
+        check_for_error(
+            ['example.mp4', '--edit', 'audio four audio'], "Error! Unknown method/operator: 'four'"
+        )
+        check_for_error(
+            ['example.mp4', '--edit', 'audio audio'], "Logic operator must be between two editing methods"
+        )
+
 
     ### Runners ###
 
@@ -489,6 +527,10 @@ def main(sys_args: Optional[List[str]]=None):
         tester.run_test(tsm_0a5_test, allow_fail=True)
         tester.run_test(tsm_2a0_test)
 
+
+    if args.category in ('api', 'all'):
+        tester.run_test(read_api_0_1)
+
     if args.category in ('sub', 'all'):
         tester.run_test(info)
         tester.run_test(levels)
@@ -500,7 +542,7 @@ def main(sys_args: Optional[List[str]]=None):
         tester.run_test(help_tests)
         tester.run_test(version_test)
         tester.run_test(parser_test)
-        tester.run_test(example_tests, allow_fail=True)
+        tester.run_test(example_tests)
         tester.run_test(url_test)
         tester.run_test(unit_tests)
         tester.run_test(backwards_range_test)
@@ -522,6 +564,8 @@ def main(sys_args: Optional[List[str]]=None):
         tester.run_test(codec_tests)
         tester.run_test(combine_tests)
         tester.run_test(motion_tests)
+        tester.run_test(edit_positive_tests)
+        tester.run_test(edit_negative_tests)
 
     tester.end()
 
