@@ -10,9 +10,9 @@ def get_stdout(cmd: List[str]) -> str:
     from subprocess import Popen, PIPE, STDOUT
 
     stdout, _ = Popen(cmd, stdout=PIPE, stderr=STDOUT).communicate()
-    return stdout.decode()
+    return stdout.decode('utf-8', 'replace')
 
-def clean_list(x: List[str], rm_chars: str) -> list:
+def clean_list(x: List[str], rm_chars: str) -> List[str]:
     new_list = []
     for item in x:
         for char in rm_chars:
@@ -24,7 +24,7 @@ def aspect_ratio(width: int, height: int) -> Union[Tuple[int, int], Tuple[None,
     if height == 0:
         return None, None
 
-    def gcd(a, b):
+    def gcd(a: int, b: int) -> int:
         while b:
             a, b = b, a % b
         return a
@@ -55,19 +55,21 @@ def human_readable_time(time_in_secs: Union[int, float]) -> str:
     return '{} {}'.format(time_in_secs, units)
 
 def open_with_system_default(path: str, log: Log) -> None:
-    from subprocess import call
+    from subprocess import run
     try:  # should work on Windows
         from os import startfile
         startfile(path)
+    except OSError:
+        pass
     except ImportError:
         try:  # should work on MacOS and most Linux versions
-            call(['open', path])
+            run(['open', path])
         except Exception:
             try: # should work on WSL2
-                call(['cmd.exe', '/C', 'start', path])
+                run(['cmd.exe', '/C', 'start', path])
             except Exception:
                 try: # should work on various other Linux distros
-                    call(['xdg-open', path])
+                    run(['xdg-open', path])
                 except Exception:
                     log.warning('Could not open output file.')
 
@@ -79,25 +81,3 @@ def append_filename(path: str, val: str) -> str:
 
     root, ext = splitext(path)
     return root + val + ext
-
-def set_output_name(path: str, inp_ext: str, making_data_file: bool, args: object) -> str:
-    from os.path import splitext
-
-    root, ext = splitext(path)
-
-    if args.export_as_json:
-        return root + '.json'
-    if args.export_to_final_cut_pro:
-        return root + '.fcpxml'
-    if args.export_to_shotcut:
-        return root + '.mlt'
-    if making_data_file:
-        return root + '.xml'
-    if args.export_as_audio:
-        return root + '_ALTERED.wav'
-    if ext == '':
-        if inp_ext is None:
-            return root
-        return root + inp_ext
-
-    return root + '_ALTERED' + ext
