@@ -1,11 +1,14 @@
 # Internal Libraries
 import os.path
 
+# Typing
+from typing import List
+
 # Included Libraries
 from .func import fnone
 
 
-def fset(cmd, option, value):
+def fset(cmd: List[str], option: str, value) -> List[str]:
     if fnone(value):
         return cmd
     return cmd + [option] + [value]
@@ -43,10 +46,7 @@ def get_acodec(args, inp, rules):
 
 
 def video_quality(cmd, args, inp, rules):
-    cmd = fset(cmd, '-crf', args.constant_rate_factor)
     cmd = fset(cmd, '-b:v', args.video_bitrate)
-    cmd = fset(cmd, '-tune', args.tune)
-    cmd = fset(cmd, '-preset', args.preset)
 
     qscale = args.video_quality_scale
 
@@ -149,7 +149,9 @@ def mux_quality_media(ffmpeg, video_stuff, rules, write_file, container, args, i
         else:
             cmd.extend(['-ar', str(args.sample_rate)])
 
+    if args.extras is not None:
+        cmd.extend(args.extras.split(' '))
     cmd.extend(['-strict', '-2'])  # Allow experimental codecs.
     cmd.extend(['-map', '0:t?', '-map', '0:d?'])  # Add input attachments and data to output.
     cmd.append(write_file)
-    ffmpeg.run_check_errors(cmd, log)
+    ffmpeg.run_check_errors(cmd, log, path=write_file)
